@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 
+from deprecation import deprecated
 from square.api_helper import APIHelper
 from square.http.api_response import ApiResponse
 from square.api.base_api import BaseApi
@@ -89,8 +90,7 @@ class CustomersApi(BaseApi):
                         body):
         """Does a POST request to /v2/customers.
 
-        Creates a new customer for a business, which can have associated cards
-        on file.
+        Creates a new customer for a business.
         You must provide at least one of the following values in your request
         to this
         endpoint:
@@ -206,8 +206,8 @@ class CustomersApi(BaseApi):
                         version=None):
         """Does a DELETE request to /v2/customers/{customer_id}.
 
-        Deletes a customer profile from a business, including any linked cards
-        on file. 
+        Deletes a customer profile from a business. This operation also
+        unlinks any associated cards on file. 
         As a best practice, you should include the `version` field in the
         request to enable [optimistic
         concurrency](https://developer.squareup.com/docs/working-with-apis/opti
@@ -336,11 +336,8 @@ class CustomersApi(BaseApi):
         version of the customer profile.
         To update a customer profile that was created by merging existing
         profiles, you must use the ID of the newly created profile.
-        You cannot use this endpoint to change cards on file. To change a card
-        on file, call [DeleteCustomerCard]($e/Customers/DeleteCustomerCard) to
-        delete the existing card and then call
-        [CreateCustomerCard]($e/Customers/CreateCustomerCard) to create a new
-        card.
+        You cannot use this endpoint to change cards on file. To make changes,
+        use the [Cards API]($e/Cards) or [Gift Cards API]($e/GiftCards).
 
         Args:
             customer_id (string): The ID of the customer to update.
@@ -388,6 +385,7 @@ class CustomersApi(BaseApi):
         _result = ApiResponse(_response, body=decoded, errors=_errors)
         return _result
 
+    @deprecated()
     def create_customer_card(self,
                              customer_id,
                              body):
@@ -447,6 +445,7 @@ class CustomersApi(BaseApi):
         _result = ApiResponse(_response, body=decoded, errors=_errors)
         return _result
 
+    @deprecated()
     def delete_customer_card(self,
                              customer_id,
                              card_id):
