@@ -17,14 +17,13 @@ class OrdersApi(BaseApi):
                      body):
         """Does a POST request to /v2/orders.
 
-        Creates a new [Order]($m/Order) which can include information on
+        Creates a new [order]($m/Order) that can include information about
         products for
         purchase and settings to apply to the purchase.
-        To pay for a created order, please refer to the 
+        To pay for a created order, see 
         [Pay for
-        Orders](https://developer.squareup.com/docs/orders-api/pay-for-orders)
-                guide.
-        You can modify open orders using the
+        Orders](https://developer.squareup.com/docs/orders-api/pay-for-orders).
+                You can modify open orders using the
         [UpdateOrder]($e/Orders/UpdateOrder) endpoint.
 
         Args:
@@ -73,8 +72,8 @@ class OrdersApi(BaseApi):
                               body):
         """Does a POST request to /v2/orders/batch-retrieve.
 
-        Retrieves a set of [Order]($m/Order)s by their IDs.
-        If a given Order ID does not exist, the ID is ignored instead of
+        Retrieves a set of [orders]($m/Order) by their IDs.
+        If a given order ID does not exist, the ID is ignored instead of
         generating an error.
 
         Args:
@@ -176,19 +175,19 @@ class OrdersApi(BaseApi):
         sales,
         returns, and exchanges regardless of how or when they entered the
         Square
-        Ecosystem (e.g. Point of Sale, Invoices, Connect APIs, etc).
-        SearchOrders requests need to specify which locations to search and
+        ecosystem (such as Point of Sale, Invoices, and Connect APIs).
+        `SearchOrders` requests need to specify which locations to search and
         define a
-        [`SearchOrdersQuery`]($m/SearchOrdersQuery) object which controls
-        how to sort or filter the results. Your SearchOrdersQuery can:
+        [SearchOrdersQuery]($m/SearchOrdersQuery) object that controls
+        how to sort or filter the results. Your `SearchOrdersQuery` can:
           Set filter criteria.
-          Set sort order.
-          Determine whether to return results as complete Order objects, or
+          Set the sort order.
+          Determine whether to return results as complete `Order` objects or
           as
         [OrderEntry]($m/OrderEntry) objects.
         Note that details for orders processed with Square Point of Sale while
         in
-        offline mode may not be transmitted to Square for up to 72 hours.
+        offline mode might not be transmitted to Square for up to 72 hours.
         Offline
         orders have a `created_at` value that reflects the time the order was
         created,
@@ -289,27 +288,27 @@ class OrdersApi(BaseApi):
                      body):
         """Does a PUT request to /v2/orders/{order_id}.
 
-        Updates an open [Order]($m/Order) by adding, replacing, or deleting
+        Updates an open [order]($m/Order) by adding, replacing, or deleting
         fields. Orders with a `COMPLETED` or `CANCELED` state cannot be
         updated.
-        An UpdateOrder request requires the following:
+        An `UpdateOrder` request requires the following:
         - The `order_id` in the endpoint path, identifying the order to
         update.
         - The latest `version` of the order to update.
         - The [sparse
         order](https://developer.squareup.com/docs/orders-api/manage-orders#spa
         rse-order-objects)
-        containing only the fields to update and the version the update is
-        being applied to.
+        containing only the fields to update and the version to which the
+        update is
+        being applied.
         - If deleting fields, the [dot notation
         paths](https://developer.squareup.com/docs/orders-api/manage-orders#on-
         dot-notation)
-        identifying fields to clear.
-        To pay for an order, please refer to the 
+        identifying the fields to clear.
+        To pay for an order, see 
         [Pay for
-        Orders](https://developer.squareup.com/docs/orders-api/pay-for-orders)
-        guide.
-
+        Orders](https://developer.squareup.com/docs/orders-api/pay-for-orders).
+        
         Args:
             order_id (string): The ID of the order to update.
             body (UpdateOrderRequest): An object containing the fields to POST
@@ -362,24 +361,24 @@ class OrdersApi(BaseApi):
         """Does a POST request to /v2/orders/{order_id}/pay.
 
         Pay for an [order]($m/Order) using one or more approved
-        [payments]($m/Payment),
+        [payments]($m/Payment)
         or settle an order with a total of `0`.
         The total of the `payment_ids` listed in the request must be equal to
         the order
         total. Orders with a total amount of `0` can be marked as paid by
         specifying an empty
         array of `payment_ids` in the request.
-        To be used with PayOrder, a payment must:
+        To be used with `PayOrder`, a payment must:
         - Reference the order by specifying the `order_id` when [creating the
         payment]($e/Payments/CreatePayment).
         Any approved payments that reference the same `order_id` not specified
         in the
-        `payment_ids` will be canceled.
+        `payment_ids` is canceled.
         - Be approved with [delayed
         capture](https://developer.squareup.com/docs/payments-api/take-payments
         #delayed-capture).
-        Using a delayed capture payment with PayOrder will complete the
-        approved payment.
+        Using a delayed capture payment with `PayOrder` completes the approved
+        payment.
 
         Args:
             order_id (string): The ID of the order being paid.
